@@ -246,3 +246,72 @@ test_that("check_extra_field_values works", {
   check_extra_field_values(c(1, NA, 2), "1") |>
     expect_equal("2")
 })
+
+test_that("check_fields_exist works", {
+  check_fields_exist(fields = character(0), expr = expr(starts_with("temp"))) %>%
+    expect_error(class = "missing_checkbox_fields")
+
+  check_fields_exist(fields = c(1, 2, 3), expr = expr(starts_with("temp"))) %>%
+    expect_no_error()
+})
+
+test_that("check_metadata_fields_exist works", {
+  metadata_valid <- tibble(
+    field_name = c("var1", "var2", "var_3"),
+  )
+  valid_cols <- c("var1", "var2", "var_3")
+
+  metadata_invalid <- tibble(
+    field_name = c("var1", "var2", "var_3_edited"),
+  )
+  invalid_cols <- c("var1", "var2", "var_3_edited")
+
+  check_metadata_fields_exist(metadata_valid, valid_cols) %>%
+    expect_no_error()
+
+  check_metadata_fields_exist(metadata_invalid, valid_cols) %>%
+    expect_error(class = "missing_metadata_checkbox_fields")
+
+  check_metadata_fields_exist(metadata_valid, invalid_cols) %>%
+    expect_error(class = "missing_metadata_checkbox_fields")
+})
+
+test_that("check_fields_are_checkboxes works", {
+  metadata <- tibble::tribble(
+    ~field_name, ~field_type,
+    "record_id", "text",
+    "text_field", "text",
+    "calc_field", "calc",
+    "checkbox___1", "checkbox",
+    "checkbox___2", "checkbox",
+    "checkbox___3", "checkbox"
+  )
+
+  metadata_filtered <- metadata %>%
+    filter("checkbox" %in% field_name)
+
+  expect_error(check_fields_are_checkboxes(metadata), class = "non_checkbox_fields")
+  expect_no_error(check_fields_are_checkboxes(metadata_filtered))
+})
+
+test_that("check_equal_col_summaries works", {
+  data <- tibble::tribble(
+    ~"id", ~"col1", ~"col2",
+    1, "A", "A1",
+    2, "B", "B1",
+    3, "C", "C1"
+  )
+
+  expect_no_error(check_equal_col_summaries(data, col1, col2))
+
+  error_data <- tibble::tribble(
+    ~"id", ~"col1", ~"col2",
+    1, "A", "A1",
+    2, "A", "A2",
+    3, "B", "B1",
+    4, "B", "B2"
+  )
+
+  check_equal_col_summaries(error_data, col1, col2) %>%
+    expect_error(class = "names_glue_multi_checkbox")
+})
